Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4555)

Unified Diff: cc/resources/ui_resource_bitmap.h

Issue 22870016: Update the nine patch layer to use UI resources (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: ccameron's fix for exisiting nine-patch uses Created 7 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: cc/resources/ui_resource_bitmap.h
diff --git a/cc/resources/ui_resource_bitmap.h b/cc/resources/ui_resource_bitmap.h
index e1b5aee0adbde5786923991311a36b041efa16e4..f10fed98125377b88b1d5fa2d8860bbc739fc22c 100644
--- a/cc/resources/ui_resource_bitmap.h
+++ b/cc/resources/ui_resource_bitmap.h
@@ -8,16 +8,20 @@
#include "base/memory/ref_counted.h"
#include "base/memory/scoped_ptr.h"
#include "cc/base/cc_export.h"
+#include "skia/ext/refptr.h"
+#include "third_party/skia/include/core/SkPixelRef.h"
#include "third_party/skia/include/core/SkTypes.h"
#include "ui/gfx/size.h"
+class SkBitmap;
+
namespace cc {
-// Ref-counted bitmap class (can’t use SkBitmap because of ETC1). Thread-safety
-// ensures that both main and impl threads can hold references to the bitmap and
-// that asynchronous uploads are allowed.
-class CC_EXPORT UIResourceBitmap
- : public base::RefCountedThreadSafe<UIResourceBitmap> {
+// A bitmap class that contains a ref-counted reference to a SkPixelRef* that
+// holds the content of the bitmap (cannot use SkBitmap because of ETC1).
+// Thread-safety (by ways of SkPixelRef) ensures that both main and impl threads
+// can hold references to the bitmap and that asynchronous uploads are allowed.
+class CC_EXPORT UIResourceBitmap {
public:
enum UIResourceFormat {
RGBA8
@@ -27,29 +31,29 @@ class CC_EXPORT UIResourceBitmap
REPEAT
};
- // Takes ownership of “pixels”.
- static scoped_refptr<UIResourceBitmap> Create(uint8_t* pixels,
- UIResourceFormat format,
- UIResourceWrapMode wrap_mode,
- gfx::Size size);
-
gfx::Size GetSize() const { return size_; }
UIResourceFormat GetFormat() const { return format_; }
UIResourceWrapMode GetWrapMode() const { return wrap_mode_; }
- uint8_t* GetPixels() { return pixels_.get(); }
+ uint8_t* GetPixels() const;
- private:
- friend class base::RefCountedThreadSafe<UIResourceBitmap>;
+ // The constructor for the UIResourceBitmap. User must ensure that |skbitmap|
+ // is immutable. The SkBitmap format should be in 32-bit RGBA. Wrap mode is
+ // unnecessary for most UI resources and is defaulted to CLAMP_TO_EDGE.
+ UIResourceBitmap(const SkBitmap& skbitmap,
+ UIResourceWrapMode wrap_mode = CLAMP_TO_EDGE);
- UIResourceBitmap();
~UIResourceBitmap();
- scoped_ptr<uint8_t[]> pixels_;
+ private:
+ void Create(const skia::RefPtr<SkPixelRef>& pixel_ref,
+ UIResourceFormat format,
+ UIResourceWrapMode wrap_mode,
+ gfx::Size size);
+
+ skia::RefPtr<SkPixelRef> pixel_ref_;
UIResourceFormat format_;
UIResourceWrapMode wrap_mode_;
gfx::Size size_;
-
- DISALLOW_COPY_AND_ASSIGN(UIResourceBitmap);
};
} // namespace cc

Powered by Google App Engine
This is Rietveld 408576698